﻿using System.Globalization;
using System.IO;
using System.Windows;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.RichTextBoxUI;
using Telerik.Windows.Controls.RichTextBoxUI.Dialogs;
using Telerik.Windows.Documents.Layout;
using Telerik.Windows.Documents.Model;
using Telerik.Windows.Documents.Proofing;
using Telerik.Windows.Documents.UI;
using System.Windows.Controls;
using System;
using Telerik.Windows.Documents.FormatProviders.OpenXml.Docx;

namespace MsWordExample
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            StyleManager.ApplicationTheme = new Office_BlueTheme();
            InitializeComponent();

            // Next method calls are required only to work around limitations for using MEF in Examples or if you are using library caching
            //this.editor.FindReplaceDialog = new FindReplaceDialog();
            //this.editor.ParagraphPropertiesDialog = new RadParagraphPropertiesDialog();
            //this.editor.FontPropertiesDialog = new FontPropertiesDialog();

            //this.editor.InsertSymbolWindow = new RadInsertSymbolDialog();
            //this.editor.InsertHyperlinkDialog = new RadInsertHyperlinkDialog();
            //this.editor.ManageBookmarksDialog = new ManageBookmarksDialog();

            //this.editor.ContextMenu = new ContextMenu();
            //this.editor.SelectionMiniToolBar = new SelectionMiniToolBar();

            //this.editor.InsertTableDialog = new InsertTableDialog();
            //this.editor.TablePropertiesDialog = new TablePropertiesDialog();
            //this.editor.TableBordersDialog = new TableBordersDialog();

            //this.editor.SpellCheckingDialog = new SpellCheckingDialog();
            //((DocumentSpellChecker)this.editor.SpellChecker).AddDictionary(new RadEn_USDictionary(), CultureInfo.InvariantCulture);
            using (Stream stream = Application.GetResourceStream(new Uri("demoDocument.docx", UriKind.Relative)).Stream)
            {
                this.RadDocument = new DocxFormatProvider().Import(stream);
            }
        }

        public RadDocument RadDocument
        {
            get
            {
                return this.editor.Document;
            }
            set
            {
                SetupNewDocument(value);
                this.editor.Document = value;
            }
        }

        private void SetupNewDocument(RadDocument document)
        {
            document.LayoutMode = DocumentLayoutMode.Paged;
            document.ParagraphDefaultSpacingAfter = 10;
            document.PageViewMargin = new SizeF(10, 10);
            document.SectionDefaultPageMargin = new Padding(95);
        }

        private bool IsSupportedImageFormat(string extension)
        {
            if (extension != null)
            {
                extension = extension.ToLower();
            }

            return extension == ".jpg" ||
                extension == ".jpeg" ||
                extension == ".png" ||
                extension == ".bmp";
        }

        private void Statistics_Click(object sender, RoutedEventArgs e)
        {
            string statistics = this.editor.Document.GetStatisticsInfo().ToString();
            MessageBox.Show(statistics, "Document Statistics", MessageBoxButton.OK);
        }

        private void ViewDocumentStructure_Click(object sender, RoutedEventArgs e)
        {
            RadWindow window = new RadWindow();

            DocumentModelTreeViewer documentTreeViewer = new DocumentModelTreeViewer();
            documentTreeViewer.DisplayDocumentLayoutTree(this.editor.Document);

            window.Content = documentTreeViewer;

            window.WindowStartupLocation = Telerik.Windows.Controls.WindowStartupLocation.CenterOwner;
            window.Width = 600;
            window.Height = 750;

            window.ShowDialog();
        }

        private void editor_Drop(object sender, DragEventArgs e)
        {
            FileInfo[] droppedFiles = e.Data.GetData(DataFormats.FileDrop) as FileInfo[];

            foreach (FileInfo droppedFile in droppedFiles)
            {
                if (this.IsSupportedImageFormat(droppedFile.Extension))
                {
                    using (Stream imageStream = droppedFile.OpenRead())
                    {
                        this.editor.InsertImage(imageStream, droppedFile.Extension);
                    }
                }
            }
        }
    }
}
